nchars_wrap: Count the number of characters per line

View source: R/nchars_wrap.R

nchars_wrapR Documentation

Count the number of characters per line

Description

Count the number of characters per line

Usage

nchars_wrap(b, w)

Arguments

b

Numeric vector for the position of line breaks between the words in w

w

Character string vector of words

Value

List with vectors for number of characters per line and the number of words per line


migest documentation built on April 4, 2026, 9:07 a.m.